################
The Lago Project
################
Lago is an add-hoc virtual framework which helps you build virtualized
environments on your server or laptop for various use cases.

For the official docs see: http://lago.readthedocs.io
